==> decoupled_toolbox-1.0.1-rc1.tar.gz: decoupled_toolbox/src/Plugin/Field/FieldFormatter/LinkDecoupledFormatter.php <==
<?php

namespace Drupal\decoupled_toolbox\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemInterface;

/**
 * Plugin implementation of the "decoupled_link" formatter.
 *
 * @FieldFormatter(
 *   id = "decoupled_link",
 *   label = @Translation("Link decoupled formatter"),
 *   field_types = {
 *     "link",
 *   }
 * )
 */
class LinkDecoupledFormatter extends GenericDecoupledFormatter {

  /**
   * {@inheritdoc}
   */
  protected function viewFieldItem(FieldItemInterface $item) {
    /* @var \Drupal\link\LinkItemInterface $item */
    /* @var \Drupal\Core\Url $url */
    // Object that holds information about a URL.
    $url = $item->getUrl();
    // getOptions() may return an empty array.
    $options = $url->getOptions();
    $url_string = $url->toString(TRUE);
    // Add url cache tags.
    $this->addProcessedFieldCacheTag($url_string->getCacheTags());
    return [
      'url' => $url_string->getGeneratedUrl(),
      'title' => $item->get('title')->getValue(),
      // Certain attributes like class can be arrays.
      // Check for that and implode them.
      'attributes' => empty($options) ? NULL : $options,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function getOutputDefinitions() {
    return [
      'url' => 'string',
      'title' => 'string',
      'attributes' => [
        'id' => 'string',
        'name' => 'string',
        'target' => 'string',
        'rel' => 'string',
        'class' => 'string',
        'accesskey' => 'string',
      ],
    ];
  }

}

==> decoupled_toolbox-1.5.1-rc10.tar.gz: decoupled_toolbox/src/Plugin/Field/FieldFormatter/LinkDecoupledFormatter.php <==
<?php

namespace Drupal\decoupled_toolbox\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemInterface;

/**
 * Plugin implementation of the "decoupled_link" formatter.
 *
 * @FieldFormatter(
 *   id = "decoupled_link",
 *   label = @Translation("Link decoupled formatter"),
 *   field_types = {
 *     "link",
 *   }
 * )
 */
class LinkDecoupledFormatter extends GenericDecoupledFormatter {

  /**
   * {@inheritdoc}
   */
  protected function viewFieldItem(FieldItemInterface $item) {
    /** @var \Drupal\link\LinkItemInterface $item */
    /** @var \Drupal\Core\Url $url */
    // Object that holds information about a URL.
    $url = $item->getUrl();
    // getOptions() may return an empty array.
    $options = $url->getOptions();
    $url_string = $url->toString(TRUE);
    // Add url cache tags.
    $this->addProcessedFieldCacheTag($url_string->getCacheTags());
    return [
      'url' => $url_string->getGeneratedUrl(),
      'title' => $item->get('title')->getValue(),
      // Certain attributes like class can be arrays.
      // Check for that and implode them.
      'attributes' => empty($options) ? NULL : $options,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function getOutputDefinitions() {
    return [
      'url' => 'string',
      'title' => 'string',
      'attributes' => [
        'id' => 'string',
        'name' => 'string',
        'target' => 'string',
        'rel' => 'string',
        'class' => 'string',
        'accesskey' => 'string',
      ],
    ];
  }

}
